Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/sys/dev/ic the kind of "firmware" was clarified.
details: https://anonhg.NetBSD.org/src/rev/0f9ab521dce3
branches: trunk
changeset: 524778:0f9ab521dce3
user: ichiro <ichiro%NetBSD.org@localhost>
date: Sat Mar 30 15:58:45 2002 +0000
description:
the kind of "firmware" was clarified.
firmware -> station firmware
diffstat:
sys/dev/ic/wi.c | 8 ++++----
1 files changed, 4 insertions(+), 4 deletions(-)
diffs (36 lines):
diff -r 4888be5f8b9f -r 0f9ab521dce3 sys/dev/ic/wi.c
--- a/sys/dev/ic/wi.c Sat Mar 30 15:53:26 2002 +0000
+++ b/sys/dev/ic/wi.c Sat Mar 30 15:58:45 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: wi.c,v 1.56 2002/03/27 08:01:22 onoe Exp $ */
+/* $NetBSD: wi.c,v 1.57 2002/03/30 15:58:45 ichiro Exp $ */
/*
* Copyright (c) 1997, 1998, 1999
@@ -70,7 +70,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: wi.c,v 1.56 2002/03/27 08:01:22 onoe Exp $");
+__KERNEL_RCSID(0, "$NetBSD: wi.c,v 1.57 2002/03/30 15:58:45 ichiro Exp $");
#define WI_HERMES_AUTOINC_WAR /* Work around data write autoinc bug. */
#define WI_HERMES_STATS_WAR /* Work around stats counter bug. */
@@ -2011,7 +2011,7 @@
break;
}
/* get firmware version */
memset(&ver, 0, sizeof(ver));
ver.wi_type = WI_RID_STA_IDENTITY;
ver.wi_len = 5;
@@ -2039,7 +2039,7 @@
(p[6] - '0') * 10 + (p[7] - '0');
}
}
- printf(", Firmware: %s %u.%u.%u\n",
+ printf(", Station Firmware: %s %u.%u.%u\n",
(sc->sc_firmware_type == WI_LUCENT ? "Lucent" :
(sc->sc_firmware_type == WI_SYMBOL ? "Symbol" : "Intersil")),
sc->sc_firmware_ver / 10000, (sc->sc_firmware_ver % 10000) / 100,
@@ -2011,7 +2011,7 @@
break;
}
- /* get firmware version */
+ /* get station firmware version */
memset(&ver, 0, sizeof(ver));
ver.wi_type = WI_RID_STA_IDENTITY;
Home |
Main Index |
Thread Index |
Old Index